package com.ruoyi.system.service.enterprise;

import com.ruoyi.system.domain.enterprise.SysUserEnterprise;

import java.util.List;


/**
 * 用户企业信息Service接口
 * 
 * @author boman
 * @date 2024-04-22
 */
public interface ISysUserEnterpriseService 
{
    /**
     * 查询用户企业信息
     * 
     * @param userId 用户企业信息主键
     * @return 用户企业信息
     */
    public List<SysUserEnterprise> selectSysUserEnterpriseByUserId(Long userId);
    public SysUserEnterprise selectSysUserEnterpriseByEnterpriseId(Long enterpriseId);

    /**
     * 查询用户企业信息列表
     * 
     * @param sysUserEnterprise 用户企业信息
     * @return 用户企业信息集合
     */
    public List<SysUserEnterprise> selectSysUserEnterpriseList(SysUserEnterprise sysUserEnterprise);

    /**
     * 新增用户企业信息
     * 
     * @param sysUserEnterprise 用户企业信息
     * @return 结果
     */
    public int insertSysUserEnterprise(SysUserEnterprise sysUserEnterprise);

    /**
     * 修改用户企业信息
     * 
     * @param sysUserEnterprise 用户企业信息
     * @return 结果
     */
    public int updateSysUserEnterprise(SysUserEnterprise sysUserEnterprise);

    /**
     * 批量删除用户企业信息
     * 
     * @param userIds 需要删除的用户企业信息主键集合
     * @return 结果
     */
    public int deleteSysUserEnterpriseByUserIds(Long[] userIds);
    public int deleteSysUserEnterpriseByEnterpriseIds(Long[] enterpriseIds);

    /**
     * 删除用户企业信息信息
     * 
     * @param userId 用户企业信息主键
     * @return 结果
     */
    public int deleteSysUserEnterpriseByUserId(Long userId);
}
